.. Dotty Dict documentation master file, created by
   sphinx-quickstart on Thu Mar 15 08:04:44 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==========
Dotty Dict
==========

Dotty Dict is a wrapper around builtin dictionary.
Provides quick access to deeply nested keys and values with dot notation.
Dotty Dict expose dictionary public API as proxy to dict implemented underneath
and should work with all dict-like objects which are instances of Mapping.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   dotty_dict
   examples
   api
   authors
   contributing


*******
LICENSE
*******

.. include:: ../LICENSE
